@@ -1,18 +1,23 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 # Author: Sebastian Raschka <sebastianraschka.com>
 #
 # License: BSD 3 clause
 
 from ._base_model import _BaseModel
-from ._cluster import _Cluster
 from ._classifier import _Classifier
-from ._regressor import _Regressor
+from ._cluster import _Cluster
 from ._iterative_model import _IterativeModel
 from ._multiclass import _MultiClass
 from ._multilayer import _MultiLayer
+from ._regressor import _Regressor
 
-
-__all__ = ["_BaseModel",
-           "_Cluster", "_Classifier", "_Regressor", "_IterativeModel",
-           "_MultiClass", "_MultiLayer"]
+__all__ = [
+    "_BaseModel",
+    "_Cluster",
+    "_Classifier",
+    "_Regressor",
+    "_IterativeModel",
+    "_MultiClass",
+    "_MultiLayer",
+]
