@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 #
 # Implementation of a Multi-layer Perceptron in Tensorflow
@@ -6,18 +6,17 @@
 #
 # License: BSD 3 clause
 
-import numpy as np
 from time import time
+
+import numpy as np
 from scipy.special import expit
-from .._base import _BaseModel
-from .._base import _IterativeModel
-from .._base import _MultiClass
-from .._base import _MultiLayer
-from .._base import _Classifier
+
+from .._base import _BaseModel, _Classifier, _IterativeModel, _MultiClass, _MultiLayer
 
 
-class MultiLayerPerceptron(_BaseModel, _IterativeModel,
-                           _MultiClass, _MultiLayer, _Classifier):
+class MultiLayerPerceptron(
+    _BaseModel, _IterativeModel, _MultiClass, _MultiLayer, _Classifier
+):
 
     """Multi-layer perceptron classifier with logistic sigmoid activations
 
@@ -80,14 +79,21 @@ class MultiLayerPerceptron(_BaseModel, _IterativeModel,
 
     """
 
-    def __init__(self, eta=0.5, epochs=50,
-                 hidden_layers=[50],
-                 n_classes=None,
-                 momentum=0.0, l1=0.0, l2=0.0,
-                 dropout=1.0,
-                 decrease_const=0.0,
-                 minibatches=1, random_seed=None,
-                 print_progress=0):
+    def __init__(
+        self,
+        eta=0.5,
+        epochs=50,
+        hidden_layers=[50],
+        n_classes=None,
+        momentum=0.0,
+        l1=0.0,
+        l2=0.0,
+        dropout=1.0,
+        decrease_const=0.0,
+        minibatches=1,
+        random_seed=None,
+        print_progress=0,
+    ):
 
         _BaseModel.__init__(self)
         _Classifier.__init__(self)
@@ -96,7 +102,7 @@ class MultiLayerPerceptron(_BaseModel, _IterativeModel,
         _MultiLayer.__init__(self)
 
         if len(hidden_layers) > 1:
-            raise AttributeError('Currently, only 1 hidden layer is supported')
+            raise AttributeError("Currently, only 1 hidden layer is supported")
         self.hidden_layers = hidden_layers
         self.eta = eta
         self.n_classes = n_classes
@@ -123,20 +129,22 @@ class MultiLayerPerceptron(_BaseModel, _IterativeModel,
             self._weight_maps, self._bias_maps = self._layermapping(
                 n_features=self._n_features,
                 n_classes=self.n_classes,
-                hidden_layers=self.hidden_layers)
+                hidden_layers=self.hidden_layers,
+            )
 
             self.w_, self.b_ = self._init_params_from_layermapping(
                 weight_maps=self._weight_maps,
                 bias_maps=self._bias_maps,
-                random_seed=self.random_seed)
+                random_seed=self.random_seed,
+            )
 
             self.cost_ = []
 
             if self.momentum != 0.0:
-                prev_grad_b_1 = np.zeros(shape=self.b_['1'].shape)
-                prev_grad_w_1 = np.zeros(shape=self.w_['1'].shape)
-                prev_grad_b_out = np.zeros(shape=self.b_['out'].shape)
-                prev_grad_w_out = np.zeros(shape=self.w_['out'].shape)
+                prev_grad_b_1 = np.zeros(shape=self.b_["1"].shape)
+                prev_grad_w_1 = np.zeros(shape=self.w_["1"].shape)
+                prev_grad_b_out = np.zeros(shape=self.b_["out"].shape)
+                prev_grad_w_out = np.zeros(shape=self.w_["out"].shape)
 
         y_enc = self._one_hot(y=y, n_labels=self.n_classes, dtype=np.float_)
 
@@ -145,10 +153,8 @@ class MultiLayerPerceptron(_BaseModel, _IterativeModel,
         rgen = np.random.RandomState(self.random_seed)
         for i in range(self.epochs):
             for idx in self._yield_minibatches_idx(
-                    rgen=rgen,
-                    n_batches=self.minibatches,
-                    data_ary=y,
-                    shuffle=True):
+                rgen=rgen, n_batches=self.minibatches, data_ary=y, shuffle=True
+            ):
 
                 net_1, act_1, net_out, act_out = self._feedforward(X[idx])
 
@@ -162,8 +168,7 @@ class MultiLayerPerceptron(_BaseModel, _IterativeModel,
 
                 # [n_samples, n_classlabels] dot [n_classlabels, n_hidden]
                 # -> [n_samples, n_hidden]
-                sigma_1 = (np.dot(sigma_out, self.w_['out'].T) *
-                           sigmoid_derivative_1)
+                sigma_1 = np.dot(sigma_out, self.w_["out"].T) * sigmoid_derivative_1
 
                 # [n_features, n_samples] dot [n_samples, n_hidden]
                 # -> [n_features, n_hidden]
@@ -178,29 +183,32 @@ class MultiLayerPerceptron(_BaseModel, _IterativeModel,
                 grad_B_out = np.sum(sigma_out, axis=0)
 
                 # LEARNING RATE ADJUSTEMENTS
-                self._decr_eta /= (1.0 + self.decrease_const * i)
+                self._decr_eta /= 1.0 + self.decrease_const * i
 
                 # REGULARIZATION AND WEIGHT UPDATES
 
-                dW_1 = (self._decr_eta * grad_W_1 +
-                        self._decr_eta * self.l2 * self.w_['1'])
+                dW_1 = (
+                    self._decr_eta * grad_W_1 + self._decr_eta * self.l2 * self.w_["1"]
+                )
 
-                dW_out = (self._decr_eta * grad_W_out +
-                          self._decr_eta * self.l2 * self.w_['out'])
+                dW_out = (
+                    self._decr_eta * grad_W_out
+                    + self._decr_eta * self.l2 * self.w_["out"]
+                )
 
                 dB_1 = self._decr_eta * grad_B_1
                 dB_out = self._decr_eta * grad_B_out
 
-                self.w_['1'] -= dW_1
-                self.b_['1'] -= dB_1
-                self.w_['out'] -= dW_out
-                self.b_['out'] -= dB_out
+                self.w_["1"] -= dW_1
+                self.b_["1"] -= dB_1
+                self.w_["out"] -= dW_out
+                self.b_["out"] -= dB_out
 
                 if self.momentum != 0.0:
-                    self.w_['1'] -= self.momentum * prev_grad_w_1
-                    self.b_['1'] -= self.momentum * prev_grad_b_1
-                    self.w_['out'] -= self.momentum * prev_grad_w_out
-                    self.b_['out'] -= self.momentum * prev_grad_b_out
+                    self.w_["1"] -= self.momentum * prev_grad_w_1
+                    self.b_["1"] -= self.momentum * prev_grad_b_1
+                    self.w_["out"] -= self.momentum * prev_grad_w_out
+                    self.b_["out"] -= self.momentum * prev_grad_b_out
                     prev_grad_b_1 = grad_B_1
                     prev_grad_w_1 = grad_W_1
                     prev_grad_b_out = grad_B_out
@@ -212,9 +220,7 @@ class MultiLayerPerceptron(_BaseModel, _IterativeModel,
 
             self.cost_.append(cost)
             if self.print_progress:
-                self._print_progress(iteration=i + 1,
-                                     n_iter=self.epochs,
-                                     cost=cost)
+                self._print_progress(iteration=i + 1, n_iter=self.epochs, cost=cost)
 
         return self
 
@@ -222,23 +228,22 @@ class MultiLayerPerceptron(_BaseModel, _IterativeModel,
 
         # [n_samples, n_features] dot [n_features, n_hidden]
         # -> [n_samples, n_hidden]
-        net_1 = np.dot(X, self.w_['1']) + self.b_['1']
+        net_1 = np.dot(X, self.w_["1"]) + self.b_["1"]
         act_1 = self._sigmoid(net_1)
 
         # [n_samples, n_hidden] dot [n_hidden, n_classlabels]
         # -> [n_samples, n_classlabels]
-        net_out = np.dot(act_1, self.w_['out']) + self.b_['out']
+        net_out = np.dot(act_1, self.w_["out"]) + self.b_["out"]
         act_out = self._softmax(net_out)
 
         return net_1, act_1, net_out, act_out
 
     def _compute_cost(self, cross_entropy):
-        L2_term = (self.l2 *
-                   (np.sum(self.w_['1'] ** 2.0) +
-                    np.sum(self.w_['out'] ** 2.0)))
+        L2_term = self.l2 * (
+            np.sum(self.w_["1"] ** 2.0) + np.sum(self.w_["out"] ** 2.0)
+        )
 
-        L1_term = (self.l1 *
-                   (np.abs(self.w_['1']).sum() + np.abs(self.w_['out']).sum()))
+        L1_term = self.l1 * (np.abs(self.w_["1"]).sum() + np.abs(self.w_["out"]).sum())
 
         cross_entropy = cross_entropy + L2_term + L1_term
         return 0.5 * np.mean(cross_entropy)
@@ -255,7 +260,7 @@ class MultiLayerPerceptron(_BaseModel, _IterativeModel,
         # return (np.exp(z.T) / np.sum(np.exp(z), axis=1)).T
 
     def _cross_entropy(self, output, y_target):
-        return - np.sum(np.log(output) * (y_target), axis=1)
+        return -np.sum(np.log(output) * (y_target), axis=1)
 
     def predict_proba(self, X):
         """Predict class probabilities of X from the net input.
