@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 #
 # Nonparametric Permutation Test
@@ -10,15 +10,23 @@ import numpy as np
 
 def _draw_bootstrap_sample(rng, X, y):
     sample_indices = np.arange(X.shape[0])
-    bootstrap_indices = rng.choice(sample_indices,
-                                   size=sample_indices.shape[0],
-                                   replace=True)
+    bootstrap_indices = rng.choice(
+        sample_indices, size=sample_indices.shape[0], replace=True
+    )
     return X[bootstrap_indices], y[bootstrap_indices]
 
 
-def bias_variance_decomp(estimator, X_train, y_train, X_test, y_test,
-                         loss='0-1_loss', num_rounds=200, random_seed=None,
-                         **fit_params):
+def bias_variance_decomp(
+    estimator,
+    X_train,
+    y_train,
+    X_test,
+    y_test,
+    loss="0-1_loss",
+    num_rounds=200,
+    random_seed=None,
+    **fit_params
+):
     """
     estimator : object
         A classifier or regressor object or class implementing both a
@@ -69,26 +77,27 @@ def bias_variance_decomp(estimator, X_train, y_train, X_test, y_test,
     http://rasbt.github.io/mlxtend/user_guide/evaluate/bias_variance_decomp/
 
     """
-    supported = ['0-1_loss', 'mse']
+    supported = ["0-1_loss", "mse"]
     if loss not in supported:
-        raise NotImplementedError('loss must be one of the following: %s' %
-                                  supported)
+        raise NotImplementedError("loss must be one of the following: %s" % supported)
 
     for ary in (X_train, y_train, X_test, y_test):
-        if hasattr(ary, 'loc'):
-            raise ValueError('The bias_variance_decomp does not '
-                             'support pandas DataFrames yet. '
-                             'Please check the inputs to '
-                             'X_train, y_train, X_test, y_test. '
-                             'If e.g., X_train is a pandas '
-                             'DataFrame, try passing it as NumPy array via '
-                             'X_train=X_train.values.')
+        if hasattr(ary, "loc"):
+            raise ValueError(
+                "The bias_variance_decomp does not "
+                "support pandas DataFrames yet. "
+                "Please check the inputs to "
+                "X_train, y_train, X_test, y_test. "
+                "If e.g., X_train is a pandas "
+                "DataFrame, try passing it as NumPy array via "
+                "X_train=X_train.values."
+            )
 
     rng = np.random.RandomState(random_seed)
 
-    if loss == '0-1_loss':
+    if loss == "0-1_loss":
         dtype = np.int64
-    elif loss == 'mse':
+    elif loss == "mse":
         dtype = np.float64
 
     all_pred = np.zeros((num_rounds, y_test.shape[0]), dtype=dtype)
@@ -97,40 +106,39 @@ def bias_variance_decomp(estimator, X_train, y_train, X_test, y_test,
         X_boot, y_boot = _draw_bootstrap_sample(rng, X_train, y_train)
 
         # Keras support
-        if estimator.__class__.__name__ in ['Sequential', 'Functional']:
+        if estimator.__class__.__name__ in ["Sequential", "Functional"]:
 
             # reset model
             for ix, layer in enumerate(estimator.layers):
-                if hasattr(estimator.layers[ix], 'kernel_initializer') and \
-                        hasattr(estimator.layers[ix], 'bias_initializer'):
-                    weight_initializer = \
-                        estimator.layers[ix].kernel_initializer
+                if hasattr(estimator.layers[ix], "kernel_initializer") and hasattr(
+                    estimator.layers[ix], "bias_initializer"
+                ):
+                    weight_initializer = estimator.layers[ix].kernel_initializer
                     bias_initializer = estimator.layers[ix].bias_initializer
 
-                    old_weights, old_biases = \
-                        estimator.layers[ix].get_weights()
+                    old_weights, old_biases = estimator.layers[ix].get_weights()
 
-                    estimator.layers[ix].set_weights([
-                        weight_initializer(shape=old_weights.shape),
-                        bias_initializer(shape=len(old_biases))])
+                    estimator.layers[ix].set_weights(
+                        [
+                            weight_initializer(shape=old_weights.shape),
+                            bias_initializer(shape=len(old_biases)),
+                        ]
+                    )
 
             estimator.fit(X_boot, y_boot, **fit_params)
             pred = estimator.predict(X_test).reshape(1, -1)
         else:
-            pred = estimator.fit(
-                X_boot, y_boot, **fit_params).predict(X_test)
+            pred = estimator.fit(X_boot, y_boot, **fit_params).predict(X_test)
         all_pred[i] = pred
 
-    if loss == '0-1_loss':
-        main_predictions = np.apply_along_axis(lambda x:
-                                               np.argmax(np.bincount(x)),
-                                               axis=0,
-                                               arr=all_pred)
+    if loss == "0-1_loss":
+        main_predictions = np.apply_along_axis(
+            lambda x: np.argmax(np.bincount(x)), axis=0, arr=all_pred
+        )
 
-        avg_expected_loss = np.apply_along_axis(lambda x:
-                                                (x != y_test).mean(),
-                                                axis=1,
-                                                arr=all_pred).mean()
+        avg_expected_loss = np.apply_along_axis(
+            lambda x: (x != y_test).mean(), axis=1, arr=all_pred
+        ).mean()
 
         avg_bias = np.sum(main_predictions != y_test) / y_test.size
 
@@ -140,18 +148,16 @@ def bias_variance_decomp(estimator, X_train, y_train, X_test, y_test,
             var += (pred != main_predictions).astype(np.int)
         var /= num_rounds
 
-        avg_var = var.sum()/y_test.shape[0]
+        avg_var = var.sum() / y_test.shape[0]
 
     else:
         avg_expected_loss = np.apply_along_axis(
-            lambda x:
-            ((x - y_test)**2).mean(),
-            axis=1,
-            arr=all_pred).mean()
+            lambda x: ((x - y_test) ** 2).mean(), axis=1, arr=all_pred
+        ).mean()
 
         main_predictions = np.mean(all_pred, axis=0)
 
-        avg_bias = np.sum((main_predictions - y_test)**2) / y_test.size
-        avg_var = np.sum((main_predictions - all_pred)**2) / all_pred.size
+        avg_bias = np.sum((main_predictions - y_test) ** 2) / y_test.size
+        avg_var = np.sum((main_predictions - all_pred) ** 2) / all_pred.size
 
     return avg_expected_loss, avg_bias, avg_var
