@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 #
 # Author: Sebastian Raschka <sebastianraschka.com>
@@ -7,15 +7,20 @@
 
 import numpy as np
 from scipy import stats
-from sklearn.model_selection import train_test_split
-from sklearn.model_selection import KFold
 from sklearn.metrics import get_scorer
+from sklearn.model_selection import KFold, train_test_split
 
 
-def paired_ttest_resampled(estimator1, estimator2, X, y,
-                           num_rounds=30, test_size=0.3,
-                           scoring=None,
-                           random_seed=None):
+def paired_ttest_resampled(
+    estimator1,
+    estimator2,
+    X,
+    y,
+    num_rounds=30,
+    test_size=0.3,
+    scoring=None,
+    random_seed=None,
+):
     """
     Implements the resampled paired t test procedure
     to compare the performance of two models
@@ -77,20 +82,20 @@ def paired_ttest_resampled(estimator1, estimator2, X, y,
     http://rasbt.github.io/mlxtend/user_guide/evaluate/paired_ttest_resampled/
 
     """
-    if (not isinstance(test_size, int) and not isinstance(test_size, float)):
-        raise ValueError('train_size must be of '
-                         'type int or float. Got %s.' % type(test_size))
+    if not isinstance(test_size, int) and not isinstance(test_size, float):
+        raise ValueError(
+            "train_size must be of " "type int or float. Got %s." % type(test_size)
+        )
 
     rng = np.random.RandomState(random_seed)
 
     if scoring is None:
-        if estimator1._estimator_type == 'classifier':
-            scoring = 'accuracy'
-        elif estimator1._estimator_type == 'regressor':
-            scoring = 'r2'
+        if estimator1._estimator_type == "classifier":
+            scoring = "accuracy"
+        elif estimator1._estimator_type == "regressor":
+            scoring = "r2"
         else:
-            raise AttributeError('Estimator must '
-                                 'be a Classifier or Regressor.')
+            raise AttributeError("Estimator must " "be a Classifier or Regressor.")
     if isinstance(scoring, str):
         scorer = get_scorer(scoring)
     else:
@@ -101,9 +106,9 @@ def paired_ttest_resampled(estimator1, estimator2, X, y,
 
         randint = rng.randint(low=0, high=32767)
 
-        X_train, X_test, y_train, y_test = \
-            train_test_split(X, y, test_size=test_size,
-                             random_state=randint)
+        X_train, X_test, y_train, y_test = train_test_split(
+            X, y, test_size=test_size, random_state=randint
+        )
 
         estimator1.fit(X_train, y_train)
         estimator2.fit(X_train, y_train)
@@ -115,19 +120,18 @@ def paired_ttest_resampled(estimator1, estimator2, X, y,
     avg_diff = np.mean(score_diff)
 
     numerator = avg_diff * np.sqrt(num_rounds)
-    denominator = np.sqrt(sum([(diff - avg_diff)**2 for diff in score_diff])
-                          / (num_rounds - 1))
+    denominator = np.sqrt(
+        sum([(diff - avg_diff) ** 2 for diff in score_diff]) / (num_rounds - 1)
+    )
     t_stat = numerator / denominator
 
-    pvalue = stats.t.sf(np.abs(t_stat), num_rounds - 1)*2.
+    pvalue = stats.t.sf(np.abs(t_stat), num_rounds - 1) * 2.0
     return float(t_stat), float(pvalue)
 
 
-def paired_ttest_kfold_cv(estimator1, estimator2, X, y,
-                          cv=10,
-                          scoring=None,
-                          shuffle=False,
-                          random_seed=None):
+def paired_ttest_kfold_cv(
+    estimator1, estimator2, X, y, cv=10, scoring=None, shuffle=False, random_seed=None
+):
     """
     Implements the k-fold paired t test procedure
     to compare the performance of two models.
@@ -195,13 +199,12 @@ def paired_ttest_kfold_cv(estimator1, estimator2, X, y,
         kf = KFold(n_splits=cv, random_state=random_seed, shuffle=shuffle)
 
     if scoring is None:
-        if estimator1._estimator_type == 'classifier':
-            scoring = 'accuracy'
-        elif estimator1._estimator_type == 'regressor':
-            scoring = 'r2'
+        if estimator1._estimator_type == "classifier":
+            scoring = "accuracy"
+        elif estimator1._estimator_type == "regressor":
+            scoring = "r2"
         else:
-            raise AttributeError('Estimator must '
-                                 'be a Classifier or Regressor.')
+            raise AttributeError("Estimator must " "be a Classifier or Regressor.")
     if isinstance(scoring, str):
         scorer = get_scorer(scoring)
     else:
@@ -223,17 +226,16 @@ def paired_ttest_kfold_cv(estimator1, estimator2, X, y,
     avg_diff = np.mean(score_diff)
 
     numerator = avg_diff * np.sqrt(cv)
-    denominator = np.sqrt(sum([(diff - avg_diff)**2 for diff in score_diff])
-                          / (cv - 1))
+    denominator = np.sqrt(
+        sum([(diff - avg_diff) ** 2 for diff in score_diff]) / (cv - 1)
+    )
     t_stat = numerator / denominator
 
-    pvalue = stats.t.sf(np.abs(t_stat), cv - 1)*2.
+    pvalue = stats.t.sf(np.abs(t_stat), cv - 1) * 2.0
     return float(t_stat), float(pvalue)
 
 
-def paired_ttest_5x2cv(estimator1, estimator2, X, y,
-                       scoring=None,
-                       random_seed=None):
+def paired_ttest_5x2cv(estimator1, estimator2, X, y, scoring=None, random_seed=None):
     """
     Implements the 5x2cv paired t test proposed
     by Dieterrich (1998)
@@ -288,19 +290,18 @@ def paired_ttest_5x2cv(estimator1, estimator2, X, y,
     rng = np.random.RandomState(random_seed)
 
     if scoring is None:
-        if estimator1._estimator_type == 'classifier':
-            scoring = 'accuracy'
-        elif estimator1._estimator_type == 'regressor':
-            scoring = 'r2'
+        if estimator1._estimator_type == "classifier":
+            scoring = "accuracy"
+        elif estimator1._estimator_type == "regressor":
+            scoring = "r2"
         else:
-            raise AttributeError('Estimator must '
-                                 'be a Classifier or Regressor.')
+            raise AttributeError("Estimator must " "be a Classifier or Regressor.")
     if isinstance(scoring, str):
         scorer = get_scorer(scoring)
     else:
         scorer = scoring
 
-    variance_sum = 0.
+    variance_sum = 0.0
     first_diff = None
 
     def score_diff(X_1, X_2, y_1, y_2):
@@ -315,22 +316,19 @@ def paired_ttest_5x2cv(estimator1, estimator2, X, y,
     for i in range(5):
 
         randint = rng.randint(low=0, high=32767)
-        X_1, X_2, y_1, y_2 = \
-            train_test_split(X, y, test_size=0.5,
-                             random_state=randint)
+        X_1, X_2, y_1, y_2 = train_test_split(X, y, test_size=0.5, random_state=randint)
 
         score_diff_1 = score_diff(X_1, X_2, y_1, y_2)
         score_diff_2 = score_diff(X_2, X_1, y_2, y_1)
-        score_mean = (score_diff_1 + score_diff_2) / 2.
-        score_var = ((score_diff_1 - score_mean)**2 +
-                     (score_diff_2 - score_mean)**2)
+        score_mean = (score_diff_1 + score_diff_2) / 2.0
+        score_var = (score_diff_1 - score_mean) ** 2 + (score_diff_2 - score_mean) ** 2
         variance_sum += score_var
         if first_diff is None:
             first_diff = score_diff_1
 
     numerator = first_diff
-    denominator = np.sqrt(1/5. * variance_sum)
+    denominator = np.sqrt(1 / 5.0 * variance_sum)
     t_stat = numerator / denominator
 
-    pvalue = stats.t.sf(np.abs(t_stat), 5)*2.
+    pvalue = stats.t.sf(np.abs(t_stat), 5) * 2.0
     return float(t_stat), float(pvalue)
