@@ -1,12 +1,11 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 # Author: Sebastian Raschka <sebastianraschka.com>
 #
 # License: BSD 3 clause
 
-from .principal_component_analysis import PrincipalComponentAnalysis
 from .linear_discriminant_analysis import LinearDiscriminantAnalysis
+from .principal_component_analysis import PrincipalComponentAnalysis
 from .rbf_kernel_pca import RBFKernelPCA
 
-__all__ = ["PrincipalComponentAnalysis", "LinearDiscriminantAnalysis",
-           "RBFKernelPCA"]
+__all__ = ["PrincipalComponentAnalysis", "LinearDiscriminantAnalysis", "RBFKernelPCA"]
