@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 #
 # Function for generating association rules
@@ -9,12 +9,12 @@
 # License: BSD 3 clause
 
 from itertools import combinations
+
 import numpy as np
 import pandas as pd
 
 
-def association_rules(df, metric="confidence",
-                      min_threshold=0.8, support_only=False):
+def association_rules(df, metric="confidence", min_threshold=0.8, support_only=False):
     """Generates a DataFrame of association rules including the
     metrics 'score', 'confidence', and 'lift'
 
@@ -77,16 +77,19 @@ def association_rules(df, metric="confidence",
 
     """
     if not df.shape[0]:
-        raise ValueError('The input DataFrame `df` containing '
-                         'the frequent itemsets is empty.')
+        raise ValueError(
+            "The input DataFrame `df` containing " "the frequent itemsets is empty."
+        )
 
     # check for mandatory columns
     if not all(col in df.columns for col in ["support", "itemsets"]):
-        raise ValueError("Dataframe needs to contain the\
-                         columns 'support' and 'itemsets'")
+        raise ValueError(
+            "Dataframe needs to contain the\
+                         columns 'support' and 'itemsets'"
+        )
 
     def conviction_helper(sAC, sA, sC):
-        confidence = sAC/sA
+        confidence = sAC / sA
         conviction = np.empty(confidence.shape, dtype=float)
         if not len(conviction.shape):
             conviction = conviction[np.newaxis]
@@ -95,8 +98,9 @@ def association_rules(df, metric="confidence",
             sA = sA[np.newaxis]
             sC = sC[np.newaxis]
         conviction[:] = np.inf
-        conviction[confidence < 1.] = ((1. - sC[confidence < 1.]) /
-                                       (1. - confidence[confidence < 1.]))
+        conviction[confidence < 1.0] = (1.0 - sC[confidence < 1.0]) / (
+            1.0 - confidence[confidence < 1.0]
+        )
 
         return conviction
 
@@ -105,29 +109,34 @@ def association_rules(df, metric="confidence",
         "antecedent support": lambda _, sA, __: sA,
         "consequent support": lambda _, __, sC: sC,
         "support": lambda sAC, _, __: sAC,
-        "confidence": lambda sAC, sA, _: sAC/sA,
-        "lift": lambda sAC, sA, sC: metric_dict["confidence"](sAC, sA, sC)/sC,
-        "leverage": lambda sAC, sA, sC: metric_dict["support"](
-             sAC, sA, sC) - sA*sC,
-        "conviction": lambda sAC, sA, sC: conviction_helper(sAC, sA, sC)
-        }
+        "confidence": lambda sAC, sA, _: sAC / sA,
+        "lift": lambda sAC, sA, sC: metric_dict["confidence"](sAC, sA, sC) / sC,
+        "leverage": lambda sAC, sA, sC: metric_dict["support"](sAC, sA, sC) - sA * sC,
+        "conviction": lambda sAC, sA, sC: conviction_helper(sAC, sA, sC),
+    }
 
-    columns_ordered = ["antecedent support", "consequent support",
-                       "support",
-                       "confidence", "lift",
-                       "leverage", "conviction"]
+    columns_ordered = [
+        "antecedent support",
+        "consequent support",
+        "support",
+        "confidence",
+        "lift",
+        "leverage",
+        "conviction",
+    ]
 
     # check for metric compliance
     if support_only:
-        metric = 'support'
+        metric = "support"
     else:
         if metric not in metric_dict.keys():
-            raise ValueError("Metric must be 'confidence' or 'lift', got '{}'"
-                             .format(metric))
+            raise ValueError(
+                "Metric must be 'confidence' or 'lift', got '{}'".format(metric)
+            )
 
     # get dict of {frequent itemset} -> support
-    keys = df['itemsets'].values
-    values = df['support'].values
+    keys = df["itemsets"].values
+    values = df["support"].values
     frozenset_vect = np.vectorize(lambda x: frozenset(x))
     frequent_items_dict = dict(zip(frozenset_vect(keys), values))
 
@@ -140,7 +149,7 @@ def association_rules(df, metric="confidence",
     for k in frequent_items_dict.keys():
         sAC = frequent_items_dict[k]
         # to find all possible combinations
-        for idx in range(len(k)-1, 0, -1):
+        for idx in range(len(k) - 1, 0, -1):
             # of antecedent and consequent
             for c in combinations(k, r=idx):
                 antecedent = frozenset(c)
@@ -157,12 +166,14 @@ def association_rules(df, metric="confidence",
                         sA = frequent_items_dict[antecedent]
                         sC = frequent_items_dict[consequent]
                     except KeyError as e:
-                        s = (str(e) + 'You are likely getting this error'
-                                      ' because the DataFrame is missing '
-                                      ' antecedent and/or consequent '
-                                      ' information.'
-                                      ' You can try using the '
-                                      ' `support_only=True` option')
+                        s = (
+                            str(e) + "You are likely getting this error"
+                            " because the DataFrame is missing "
+                            " antecedent and/or consequent "
+                            " information."
+                            " You can try using the "
+                            " `support_only=True` option"
+                        )
                         raise KeyError(s)
                     # check for the threshold
 
@@ -174,21 +185,21 @@ def association_rules(df, metric="confidence",
 
     # check if frequent rule was generated
     if not rule_supports:
-        return pd.DataFrame(
-            columns=["antecedents", "consequents"] + columns_ordered)
+        return pd.DataFrame(columns=["antecedents", "consequents"] + columns_ordered)
 
     else:
         # generate metrics
         rule_supports = np.array(rule_supports).T.astype(float)
         df_res = pd.DataFrame(
             data=list(zip(rule_antecedents, rule_consequents)),
-            columns=["antecedents", "consequents"])
+            columns=["antecedents", "consequents"],
+        )
 
         if support_only:
             sAC = rule_supports[0]
             for m in columns_ordered:
                 df_res[m] = np.nan
-            df_res['support'] = sAC
+            df_res["support"] = sAC
 
         else:
             sAC = rule_supports[0]
