@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 #
 # A function for plotting learning curves of classifiers.
@@ -6,21 +6,25 @@
 #
 # License: BSD 3 clause
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 
 
-def plot_learning_curves(X_train, y_train,
-                         X_test, y_test,
-                         clf,
-                         train_marker='o',
-                         test_marker='^',
-                         scoring='misclassification error',
-                         suppress_plot=False,
-                         print_model=True,
-                         title_fontsize=12,
-                         style='default',
-                         legend_loc='best'):
+def plot_learning_curves(
+    X_train,
+    y_train,
+    X_test,
+    y_test,
+    clf,
+    train_marker="o",
+    test_marker="^",
+    scoring="misclassification error",
+    suppress_plot=False,
+    print_model=True,
+    title_fontsize=12,
+    style="default",
+    legend_loc="best",
+):
     """Plots learning curves of a classifier.
 
     Parameters
@@ -70,36 +74,37 @@ def plot_learning_curves(X_train, y_train,
     http://rasbt.github.io/mlxtend/user_guide/plotting/plot_learning_curves/
 
     """
-    if scoring != 'misclassification error':
+    if scoring != "misclassification error":
         from sklearn import metrics
 
         scoring_func = {
-            'accuracy': metrics.accuracy_score,
-            'average_precision': metrics.average_precision_score,
-            'f1': metrics.f1_score,
-            'f1_micro': metrics.f1_score,
-            'f1_macro': metrics.f1_score,
-            'f1_weighted': metrics.f1_score,
-            'f1_samples': metrics.f1_score,
-            'log_loss': metrics.log_loss,
-            'precision': metrics.precision_score,
-            'recall': metrics.recall_score,
-            'roc_auc': metrics.roc_auc_score,
-            'adjusted_rand_score': metrics.adjusted_rand_score,
-            'mean_absolute_error': metrics.mean_absolute_error,
-            'mean_squared_error': metrics.mean_squared_error,
-            'median_absolute_error': metrics.median_absolute_error,
-            'r2': metrics.r2_score}
+            "accuracy": metrics.accuracy_score,
+            "average_precision": metrics.average_precision_score,
+            "f1": metrics.f1_score,
+            "f1_micro": metrics.f1_score,
+            "f1_macro": metrics.f1_score,
+            "f1_weighted": metrics.f1_score,
+            "f1_samples": metrics.f1_score,
+            "log_loss": metrics.log_loss,
+            "precision": metrics.precision_score,
+            "recall": metrics.recall_score,
+            "roc_auc": metrics.roc_auc_score,
+            "adjusted_rand_score": metrics.adjusted_rand_score,
+            "mean_absolute_error": metrics.mean_absolute_error,
+            "mean_squared_error": metrics.mean_squared_error,
+            "median_absolute_error": metrics.median_absolute_error,
+            "r2": metrics.r2_score,
+        }
 
         if scoring not in scoring_func.keys():
-            raise AttributeError('scoring must be in', scoring_func.keys())
+            raise AttributeError("scoring must be in", scoring_func.keys())
 
     else:
+
         def misclf_err(y_predict, y):
             return (y_predict != y).sum() / float(len(y))
 
-        scoring_func = {
-            'misclassification error': misclf_err}
+        scoring_func = {"misclassification error": misclf_err}
 
     training_errors = []
     test_errors = []
@@ -119,19 +124,27 @@ def plot_learning_curves(X_train, y_train,
 
     if not suppress_plot:
         with plt.style.context(style):
-            plt.plot(np.arange(10, 101, 10), training_errors,
-                     label='training set', marker=train_marker)
-            plt.plot(np.arange(10, 101, 10), test_errors,
-                     label='test set', marker=test_marker)
-            plt.xlabel('Training set size in percent')
+            plt.plot(
+                np.arange(10, 101, 10),
+                training_errors,
+                label="training set",
+                marker=train_marker,
+            )
+            plt.plot(
+                np.arange(10, 101, 10),
+                test_errors,
+                label="test set",
+                marker=test_marker,
+            )
+            plt.xlabel("Training set size in percent")
 
     if not suppress_plot:
         with plt.style.context(style):
-            plt.ylabel('Performance ({})'.format(scoring))
+            plt.ylabel("Performance ({})".format(scoring))
             if print_model:
                 plt.title(
-                    'Learning Curves\n\n{}\n'.format(model),
-                    fontsize=title_fontsize)
+                    "Learning Curves\n\n{}\n".format(model), fontsize=title_fontsize
+                )
             plt.legend(loc=legend_loc, numpoints=1)
             plt.xlim([0, 110])
             max_y = max(max(test_errors), max(training_errors))
