@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 # Author: Sebastian Raschka <sebastianraschka.com>
 #
@@ -9,18 +9,21 @@ import matplotlib.pyplot as plt
 import numpy as np
 
 
-def plot_confusion_matrix(conf_mat,
-                          hide_spines=False,
-                          hide_ticks=False,
-                          figsize=None,
-                          cmap=None,
-                          colorbar=False,
-                          show_absolute=True,
-                          show_normed=False,
-                          class_names=None,
-                          figure=None,
-                          axis=None,
-                          fontcolor_threshold=0.5):
+def plot_confusion_matrix(
+    conf_mat,
+    hide_spines=False,
+    hide_ticks=False,
+    figsize=None,
+    cmap=None,
+    colorbar=False,
+    show_absolute=True,
+    show_normed=False,
+    norm_colormap=None,
+    class_names=None,
+    figure=None,
+    axis=None,
+    fontcolor_threshold=0.5,
+):
     """Plot a confusion matrix via matplotlib.
 
     Parameters
@@ -56,6 +59,10 @@ def plot_confusion_matrix(conf_mat,
         At least one of  `show_absolute` or `show_normed`
         must be True.
 
+    norm_colormap : bool (default: False)
+        Matplotlib color normalization object to normalize the
+        color scale, e.g., `matplotlib.colors.LogNorm()`.
+
     class_names : array-like, shape = [n_classes] (default: None)
         List of class names.
         If not `None`, ticks will be set to these values.
@@ -85,13 +92,14 @@ def plot_confusion_matrix(conf_mat,
 
     """
     if not (show_absolute or show_normed):
-        raise AssertionError('Both show_absolute and show_normed are False')
+        raise AssertionError("Both show_absolute and show_normed are False")
     if class_names is not None and len(class_names) != len(conf_mat):
-        raise AssertionError('len(class_names) should be equal to number of'
-                             'classes in the dataset')
+        raise AssertionError(
+            "len(class_names) should be equal to number of" "classes in the dataset"
+        )
 
     total_samples = conf_mat.sum(axis=1)[:, np.newaxis]
-    normed_conf_mat = conf_mat.astype('float') / total_samples
+    normed_conf_mat = conf_mat.astype("float") / total_samples
 
     if figure is None and axis is None:
         fig, ax = plt.subplots(figsize=figsize)
@@ -106,12 +114,12 @@ def plot_confusion_matrix(conf_mat,
         cmap = plt.cm.Blues
 
     if figsize is None:
-        figsize = (len(conf_mat)*1.25, len(conf_mat)*1.25)
+        figsize = (len(conf_mat) * 1.25, len(conf_mat) * 1.25)
 
     if show_normed:
-        matshow = ax.matshow(normed_conf_mat, cmap=cmap)
+        matshow = ax.matshow(normed_conf_mat, cmap=cmap, norm=norm_colormap)
     else:
-        matshow = ax.matshow(conf_mat, cmap=cmap)
+        matshow = ax.matshow(conf_mat, cmap=cmap, norm=norm_colormap)
 
     if colorbar:
         fig.colorbar(matshow)
@@ -120,45 +128,56 @@ def plot_confusion_matrix(conf_mat,
         for j in range(conf_mat.shape[1]):
             cell_text = ""
             if show_absolute:
-                cell_text += format(conf_mat[i, j], 'd')
+                num = conf_mat[i, j].astype(np.int64)
+                cell_text += format(num, "d")
                 if show_normed:
-                    cell_text += "\n" + '('
-                    cell_text += format(normed_conf_mat[i, j], '.2f') + ')'
+                    cell_text += "\n" + "("
+                    cell_text += format(normed_conf_mat[i, j], ".2f") + ")"
             else:
-                cell_text += format(normed_conf_mat[i, j], '.2f')
+                cell_text += format(normed_conf_mat[i, j], ".2f")
 
             if show_normed:
-                ax.text(x=j,
-                        y=i,
-                        s=cell_text,
-                        va='center',
-                        ha='center',
-                        color=("white" if normed_conf_mat[i, j]
-                               > 1 * fontcolor_threshold else "black"))
+                ax.text(
+                    x=j,
+                    y=i,
+                    s=cell_text,
+                    va="center",
+                    ha="center",
+                    color=(
+                        "white"
+                        if normed_conf_mat[i, j] > 1 * fontcolor_threshold
+                        else "black"
+                    ),
+                )
             else:
-                ax.text(x=j,
-                        y=i,
-                        s=cell_text,
-                        va='center',
-                        ha='center',
-                        color="white" if conf_mat[i, j]
-                        > np.max(conf_mat) * fontcolor_threshold else "black")
+                ax.text(
+                    x=j,
+                    y=i,
+                    s=cell_text,
+                    va="center",
+                    ha="center",
+                    color="white"
+                    if conf_mat[i, j] > np.max(conf_mat) * fontcolor_threshold
+                    else "black",
+                )
     if class_names is not None:
         tick_marks = np.arange(len(class_names))
-        plt.xticks(tick_marks, class_names, rotation=45)
+        plt.xticks(
+            tick_marks, class_names, rotation=45, ha="right", rotation_mode="anchor"
+        )
         plt.yticks(tick_marks, class_names)
 
     if hide_spines:
-        ax.spines['right'].set_visible(False)
-        ax.spines['top'].set_visible(False)
-        ax.spines['left'].set_visible(False)
-        ax.spines['bottom'].set_visible(False)
-    ax.yaxis.set_ticks_position('left')
-    ax.xaxis.set_ticks_position('bottom')
+        ax.spines["right"].set_visible(False)
+        ax.spines["top"].set_visible(False)
+        ax.spines["left"].set_visible(False)
+        ax.spines["bottom"].set_visible(False)
+    ax.yaxis.set_ticks_position("left")
+    ax.xaxis.set_ticks_position("bottom")
     if hide_ticks:
         ax.axes.get_yaxis().set_ticks([])
         ax.axes.get_xaxis().set_ticks([])
 
-    plt.xlabel('predicted label')
-    plt.ylabel('true label')
+    plt.xlabel("predicted label")
+    plt.ylabel("true label")
     return fig, ax
