@@ -1,19 +1,24 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 # Author: Sebastian Raschka <sebastianraschka.com>
 #
 # License: BSD 3 clause
 
-from .mean_centering import MeanCenterer
-from .shuffle import shuffle_arrays_unison
-from .scaling import minmax_scaling
-from .scaling import standardize
-from .dense_transformer import DenseTransformer
 from .copy_transformer import CopyTransformer
+from .dense_transformer import DenseTransformer
+from .mean_centering import MeanCenterer
 from .onehot import one_hot
+from .scaling import minmax_scaling, standardize
+from .shuffle import shuffle_arrays_unison
 from .transactionencoder import TransactionEncoder
 
-
-__all__ = ["MeanCenterer", "shuffle_arrays_unison", "CopyTransformer",
-           "minmax_scaling", "standardize", "DenseTransformer",
-           "one_hot", "TransactionEncoder"]
+__all__ = [
+    "MeanCenterer",
+    "shuffle_arrays_unison",
+    "CopyTransformer",
+    "minmax_scaling",
+    "standardize",
+    "DenseTransformer",
+    "one_hot",
+    "TransactionEncoder",
+]
