@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 # Author: Sebastian Raschka <sebastianraschka.com>
 #
@@ -10,8 +10,11 @@ if sys.version_info >= (3, 0):
     from .names import generalize_names
     from .names import generalize_names_duplcheck
 
-from .tokenizer import tokenizer_words_and_emoticons
-from .tokenizer import tokenizer_emoticons
+from .tokenizer import tokenizer_emoticons, tokenizer_words_and_emoticons
 
-__all__ = ["generalize_names", "generalize_names_duplcheck",
-           "tokenizer_words_and_emoticons", "tokenizer_emoticons"]
+__all__ = [
+    "generalize_names",
+    "generalize_names_duplcheck",
+    "tokenizer_words_and_emoticons",
+    "tokenizer_emoticons",
+]
