@@ -1,12 +1,11 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 # Author: Sebastian Raschka <sebastianraschka.com>
 #
 # License: BSD 3 clause
 
+from .checking import check_Xy, format_kwarg_dictionaries
 from .counter import Counter
 from .testing import assert_raises
-from .checking import check_Xy, format_kwarg_dictionaries
 
-__all__ = ["Counter", "assert_raises", "check_Xy",
-           "format_kwarg_dictionaries"]
+__all__ = ["Counter", "assert_raises", "check_Xy", "format_kwarg_dictionaries"]
