@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2020
+# Sebastian Raschka 2014-2022
 # mlxtend Machine Learning Library Extensions
 #
 # A counter class for printing the progress of an iterator.
@@ -27,8 +27,9 @@ def assert_raises(exception_type, message, func, *args, **kwargs):
     except exception_type as e:
         error_message = str(e)
         if message and message not in error_message:
-            raise AssertionError("Error message differs from the expected"
-                                 " string: %r. Got error message: %r" %
-                                 (message, error_message))
+            raise AssertionError(
+                "Error message differs from the expected"
+                " string: %r. Got error message: %r" % (message, error_message)
+            )
     else:
-        raise AssertionError('%s not raised.' % exception_type.__name__)
+        raise AssertionError("%s not raised." % exception_type.__name__)
